summaryrefslogtreecommitdiffstats
path: root/chromium/ui/base/l10n/l10n_util_collator.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/ui/base/l10n/l10n_util_collator.h')
-rw-r--r--chromium/ui/base/l10n/l10n_util_collator.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/chromium/ui/base/l10n/l10n_util_collator.h b/chromium/ui/base/l10n/l10n_util_collator.h
index a0bfb92ebbc..e1b91abd14a 100644
--- a/chromium/ui/base/l10n/l10n_util_collator.h
+++ b/chromium/ui/base/l10n/l10n_util_collator.h
@@ -13,7 +13,7 @@
#include "base/i18n/string_compare.h"
#include "base/memory/scoped_ptr.h"
#include "third_party/icu/source/i18n/unicode/coll.h"
-#include "ui/base/ui_export.h"
+#include "ui/base/ui_base_export.h"
namespace l10n_util {
@@ -82,7 +82,7 @@ void SortStringsUsingMethod(const std::string& locale,
// Compares two elements' string keys and returns true if the first element's
// string key is less than the second element's string key. The Element must
// have a method like the follow format to return the string key.
-// const string16& GetStringKey() const;
+// const base::string16& GetStringKey() const;
// This uses the locale specified in the constructor.
template <class Element>
class StringComparator : public std::binary_function<const Element&,
@@ -105,8 +105,8 @@ class StringComparator : public std::binary_function<const Element&,
icu::Collator* collator_;
};
-// Specialization of operator() method for string16 version.
-template <> UI_EXPORT
+// Specialization of operator() method for base::string16 version.
+template <> UI_BASE_EXPORT
bool StringComparator<base::string16>::operator()(const base::string16& lhs,
const base::string16& rhs);